package Empyrion;
our $AUTHORITY = 'cpan:GETTY';
# ABSTRACT: Modules around Empyrion - Galactical Survial
$Empyrion::VERSION = '0.003';
use strict;
use warnings;

1;

__END__

=pod

=head1 NAME

Empyrion - Modules around Empyrion - Galactical Survial

=head1 VERSION

version 0.003

=head1 AUTHOR

Torsten Raudssus <torsten@raudss.us>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
